@@ -223,7 +223,7 @@ r6 = room {
 	end,
 	dsc = [[Урок 6. Перемещение - Часть II^^
 		Теперь перейдите на последний урок.]],
-	way = { 'r1', 'r2', 'r3', 'r4', 'r6', 'theend'},
+	way = { 'r1', 'r2', 'r3', 'r4', 'r5', 'theend'},
 };
 
 theend = room {
@@ -233,7 +233,7 @@ theend = room {
 		нажмите мышью на символ меню (справа снизу).^^
 		Теперь Вы готовы к игре. Удачи!!!^^
 		Игры для INSTEAD можно скачать здесь: ]]..txtu("http://instead.syscall.ru")..[[^^
-		В обучении использован трек Instead game-engine от svenzzon.]],
+		В обучении использован трек "Instead game-engine" от svenzzon.]],
 	obj = { vway('keys', 'Посмотреть {список клавиш}.', 'help')},
 };
 
@@ -273,7 +273,6 @@ help2 = room {
 	nam = 'Параметры командной строки',
 	dsc = [[
 	-nosound - запуск без звука;^
-	-alsa - принудительное использование alsa (только для Linux);^
 	-debug - отладочный режим для разработчика игр;^
 	-theme <тема> - выбор темы;^
 	-game <игра> - выбор игры;^
